load_cached_token

Function load_cached_token 

pub fn load_cached_token() -> Option<SavedToken>
Loads a cached token from either a file or the system keyring.

  • If GCLOUD_IDENTITY_TOKEN_PATH is set, the token will be loaded from the specified file.
  • Otherwise, it attempts to read from the OS keyring using a fixed service name and the default user identifier "default".

Returns

An optional SavedToken if the token was found and deserialized.